OpenStack Sphinx Extensions
===========================

Theme and extension support for Sphinx documentation from the
OpenStack project.

To use the theme, add ``'oslo.sphinx'`` to the ``extensions`` list in
the ``conf.py`` file in your Sphinx project.
